@@ -19,23 +19,34 @@ def setup_early_environment(argv):
     WHY: Some commands need special environment handling before any logging
     or service initialization occurs.
 
+    CRITICAL: Suppress ALL logging by default until setup_mcp_server_logging()
+    configures the user's preference. This prevents early loggers (like
+    ProjectInitializer and service.* loggers) from logging at INFO level before
+    we know the user's logging preference.
+
     Args:
         argv: Command line arguments
 
     Returns:
         Processed argv list
     """
+    import logging
+
     # Disable telemetry and set cleanup flags early
     os.environ.setdefault("DISABLE_TELEMETRY", "1")
     os.environ.setdefault("CLAUDE_MPM_SKIP_CLEANUP", "0")
 
-    # EARLY CHECK: Suppress logging for configure command
+    # CRITICAL: Suppress ALL logging by default
+    # This catches all loggers (claude_mpm.*, service.*, framework_loader, etc.)
+    # This will be overridden by setup_mcp_server_logging() based on user preference
+    logging.getLogger().setLevel(logging.CRITICAL + 1)  # Root logger catches everything
+
+    # Process argv
     if argv is None:
         argv = sys.argv[1:]
-    if "configure" in argv or (len(argv) > 0 and argv[0] == "configure"):
-        import logging
 
-        logging.getLogger("claude_mpm").setLevel(logging.WARNING)
+    # EARLY CHECK: Additional suppression for configure command
+    if "configure" in argv or (len(argv) > 0 and argv[0] == "configure"):
         os.environ["CLAUDE_MPM_SKIP_CLEANUP"] = "1"
 
     return argv
@@ -79,6 +90,62 @@ def setup_configure_command_environment(args):
         logging.getLogger("claude_mpm").setLevel(logging.WARNING)
 
 
+def deploy_bundled_skills():
+    """
+    Deploy bundled Claude Code skills on startup.
+
+    WHY: Automatically deploy skills from the bundled/ directory to .claude/skills/
+    to ensure skills are available for agents without manual intervention.
+
+    DESIGN DECISION: Deployment happens silently on startup with logging only.
+    Failures are logged but don't block startup to ensure claude-mpm remains
+    functional even if skills deployment fails. Respects auto_deploy config setting.
+    """
+    try:
+        # Check if auto-deploy is disabled in config
+        from ..config.config_loader import ConfigLoader
+
+        config_loader = ConfigLoader()
+        try:
+            config = config_loader.load_config()
+            skills_config = config.get("skills", {})
+            if not skills_config.get("auto_deploy", True):
+                # Auto-deploy disabled, skip silently
+                return
+        except Exception:
+            # If config loading fails, assume auto-deploy is enabled (default)
+            pass
+
+        # Import and run skills deployment
+        from ..skills.skills_service import SkillsService
+
+        skills_service = SkillsService()
+        deployment_result = skills_service.deploy_bundled_skills()
+
+        # Log results
+        from ..core.logger import get_logger
+
+        logger = get_logger("cli")
+
+        if deployment_result.get("deployed"):
+            logger.info(
+                f"Skills: Deployed {len(deployment_result['deployed'])} skill(s)"
+            )
+
+        if deployment_result.get("errors"):
+            logger.warning(
+                f"Skills: {len(deployment_result['errors'])} skill(s) failed to deploy"
+            )
+
+    except Exception as e:
+        # Import logger here to avoid circular imports
+        from ..core.logger import get_logger
+
+        logger = get_logger("cli")
+        logger.debug(f"Failed to deploy bundled skills: {e}")
+        # Continue execution - skills deployment failure shouldn't block startup
+
+
 def discover_and_link_runtime_skills():
     """
     Discover and link runtime skills from user/project directories.
@@ -104,6 +171,67 @@ def discover_and_link_runtime_skills():
         # Continue execution - skills discovery failure shouldn't block startup
 
 
+def deploy_output_style_on_startup():
+    """
+    Deploy claude-mpm output style to Claude Code on CLI startup.
+
+    WHY: Automatically deploy and activate the output style to ensure consistent,
+    professional communication without emojis and exclamation points. This ensures
+    the style is available even when using Claude Code directly (not via chat command).
+
+    DESIGN DECISION: This is non-blocking and idempotent. It uses OutputStyleManager
+    which handles version detection, file deployment, and settings activation.
+    Only works for Claude Code >= 1.0.83.
+    """
+    try:
+        from pathlib import Path
+
+        from ..core.output_style_manager import OutputStyleManager
+
+        # Create OutputStyleManager instance
+        output_style_manager = OutputStyleManager()
+
+        # Check if Claude Code supports output styles
+        if not output_style_manager.supports_output_styles():
+            # Silently skip - version too old or Claude not installed
+            return
+
+        # Check if already deployed and active
+        settings_file = Path.home() / ".claude" / "settings.json"
+        output_style_file = Path.home() / ".claude" / "output-styles" / "claude-mpm.md"
+
+        if settings_file.exists() and output_style_file.exists():
+            try:
+                import json
+
+                settings = json.loads(settings_file.read_text())
+                if settings.get("activeOutputStyle") == "claude-mpm":
+                    # Already deployed and active
+                    return
+            except Exception:
+                pass  # Continue with deployment if we can't read settings
+
+        # Read OUTPUT_STYLE.md content
+        output_style_path = Path(__file__).parent.parent / "agents" / "OUTPUT_STYLE.md"
+
+        if not output_style_path.exists():
+            # No output style file to deploy
+            return
+
+        output_style_content = output_style_path.read_text()
+
+        # Deploy the output style (deploys file and activates it)
+        output_style_manager.deploy_output_style(output_style_content)
+
+    except Exception as e:
+        # Non-critical - log but don't fail startup
+        from ..core.logger import get_logger
+
+        logger = get_logger("cli")
+        logger.debug(f"Failed to deploy output style: {e}")
+        # Continue execution - output style deployment shouldn't block startup
+
+
 def run_background_services():
     """
     Initialize all background services on startup.
@@ -114,7 +242,9 @@ def run_background_services():
     check_mcp_auto_configuration()
     verify_mcp_gateway_startup()
     check_for_updates_async()
+    deploy_bundled_skills()
     discover_and_link_runtime_skills()
+    deploy_output_style_on_startup()
 
 
 def setup_mcp_server_logging(args):
@@ -228,12 +358,12 @@ def check_mcp_auto_configuration():
         mcp_manager = MCPConfigManager()
 
         # Fix any corrupted installations first
-        fix_success, fix_message = mcp_manager.fix_mcp_service_issues()
+        _fix_success, fix_message = mcp_manager.fix_mcp_service_issues()
         if fix_message and "Fixed:" in fix_message:
             logger.info(f"MCP service fixes applied: {fix_message}")
 
         # Ensure all services are configured correctly
-        config_success, config_message = mcp_manager.ensure_mcp_services_configured()
+        _config_success, config_message = mcp_manager.ensure_mcp_services_configured()
         if config_message and "Added MCP services" in config_message:
             logger.info(f"MCP services configured: {config_message}")
 
@@ -414,7 +544,7 @@ def check_for_updates_async():
 
     DESIGN DECISION: This is non-blocking and non-critical - failures are logged
     but don't prevent startup. Only runs for pip/pipx/npm installations, skips
-    editable/development installations.
+    editable/development installations. Respects user configuration settings.
     """
 
     def run_update_check():
@@ -423,11 +553,27 @@ def check_for_updates_async():
         try:
             import asyncio
 
+            from ..core.config import Config
             from ..core.logger import get_logger
             from ..services.self_upgrade_service import SelfUpgradeService
 
             logger = get_logger("upgrade_check")
 
+            # Load configuration
+            config = Config()
+            updates_config = config.get("updates", {})
+
+            # Check if update checking is enabled
+            if not updates_config.get("check_enabled", True):
+                logger.debug("Update checking disabled in configuration")
+                return
+
+            # Check frequency setting
+            frequency = updates_config.get("check_frequency", "daily")
+            if frequency == "never":
+                logger.debug("Update checking frequency set to 'never'")
+                return
+
             # Create new event loop for this thread
             loop = asyncio.new_event_loop()
             asyncio.set_event_loop(loop)
@@ -442,8 +588,16 @@ def check_for_updates_async():
                 logger.debug("Skipping version check for editable installation")
                 return
 
+            # Get configuration values
+            check_claude_code = updates_config.get("check_claude_code", True)
+            auto_upgrade = updates_config.get("auto_upgrade", False)
+
             # Check and prompt for upgrade if available (non-blocking)
-            loop.run_until_complete(upgrade_service.check_and_prompt_on_startup())
+            loop.run_until_complete(
+                upgrade_service.check_and_prompt_on_startup(
+                    auto_upgrade=auto_upgrade, check_claude_code=check_claude_code
+                )
+            )
 
         except Exception as e:
             # Non-critical - log but don't fail startup
