@@ -4,6 +4,7 @@ This module consolidates all magic numbers and configuration constants
 that were previously scattered throughout the codebase.
 """
 
+from pathlib import Path
 from typing import Tuple
 
 
@@ -214,7 +215,7 @@ class Defaults:
     DEFAULT_TEMPERATURE = 0.5
 
     # Logging defaults
-    DEFAULT_LOG_LEVEL = "INFO"
+    DEFAULT_LOG_LEVEL = "OFF"
     DEFAULT_LOG_FORMAT = "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
 
     # Session defaults
@@ -294,3 +295,67 @@ SOCKETIO_PORT_RANGE = NetworkConfig.SOCKETIO_PORT_RANGE
 QUERY_TIMEOUT = TimeoutConfig.QUERY_TIMEOUT
 MAX_RETRIES = RetryConfig.MAX_RETRIES
 DEFAULT_TIMEOUT = TimeoutConfig.DEFAULT_TIMEOUT
+
+
+# ==============================================================================
+# NEW ORGANIZED CONSTANTS (Phase 1 Refactoring)
+# ==============================================================================
+
+
+class NetworkPorts:
+    """Network port configuration."""
+
+    # Use existing values from NetworkConfig
+    DEFAULT_SOCKETIO = NetworkConfig.DEFAULT_SOCKETIO_PORT
+    DEFAULT_DASHBOARD = NetworkConfig.DEFAULT_DASHBOARD_PORT
+    PORT_RANGE_START = NetworkConfig.SOCKETIO_PORT_RANGE[0]
+    PORT_RANGE_END = NetworkConfig.SOCKETIO_PORT_RANGE[1]
+
+    @classmethod
+    def get_port_range(cls) -> range:
+        """Get the valid port range."""
+        return range(cls.PORT_RANGE_START, cls.PORT_RANGE_END + 1)
+
+
+class ProjectPaths:
+    """Project-specific paths and directories."""
+
+    # Claude directories
+    CLAUDE_DIR = ".claude"
+    CLAUDE_AGENTS_DIR = ".claude/agents"
+    CLAUDE_CONFIG_FILE = ".claude/config.yaml"
+
+    # MPM directories
+    MPM_DIR = ".claude-mpm"
+    MPM_SESSION_DIR = ".claude-mpm/session"
+    MPM_PROMPTS_DIR = ".claude-mpm/prompts"
+    MPM_LOGS_DIR = ".claude-mpm/logs"
+    MPM_CONFIG_DIR = ".claude-mpm/config"
+    MPM_MEMORY_DIR = ".claude-mpm/memory"
+    MPM_CACHE_DIR = ".claude-mpm/cache"
+
+    # Config files
+    MPM_CONFIG_FILE = "config.yaml"
+    AGENT_CONFIG_FILE = "agent_config.yaml"
+    EXPERIMENTAL_CONFIG = "experimental.json"
+    SOCKETIO_CONFIG = "socketio_config.yaml"
+
+    # Special files
+    EXPERIMENTAL_ACCEPTED = ".experimental_accepted"
+    VERSION_FILE = "VERSION"
+    BUILD_NUMBER_FILE = "BUILD_NUMBER"
+
+    @classmethod
+    def get_mpm_home(cls) -> Path:
+        """Get the MPM home directory."""
+        return Path.home() / cls.MPM_DIR
+
+    @classmethod
+    def get_project_mpm_dir(cls) -> Path:
+        """Get the project-specific MPM directory."""
+        return Path.cwd() / cls.MPM_DIR
+
+    @classmethod
+    def get_claude_dir(cls) -> Path:
+        """Get the Claude directory."""
+        return Path.cwd() / cls.CLAUDE_DIR
