@@ -13,7 +13,6 @@ that supports:
 
 import inspect
 import threading
-from abc import ABC
 from enum import Enum
 from typing import Any, Callable, Dict, List, Optional, Set, Type, TypeVar, Union
 
@@ -76,22 +75,17 @@ class ServiceRegistration:
         # Get constructor parameters
         if inspect.isclass(self.implementation):
             return container.create_instance(self.implementation, self.dependencies)
-        else:
-            # It's already an instance or callable
-            return self.implementation
+        # It's already an instance or callable
+        return self.implementation
 
 
 class CircularDependencyError(Exception):
     """Raised when circular dependencies are detected."""
 
-    pass
-
 
 class ServiceNotFoundError(Exception):
     """Raised when a requested service is not registered."""
 
-    pass
-
 
 class ServiceScope:
     """
@@ -337,17 +331,16 @@ class DIContainer(IServiceContainer):
                 if not hasattr(self, "_named_singletons"):
                     self._named_singletons = {}
                 self._named_singletons[named_key] = instance
+        # Normal registration without name
+        elif instance is not None:
+            self._register_internal(interface, instance=instance)
+        elif implementation is not None and not inspect.isclass(implementation):
+            # It's an instance passed as implementation (backward compatibility)
+            self._register_internal(interface, instance=implementation)
         else:
-            # Normal registration without name
-            if instance is not None:
-                self._register_internal(interface, instance=instance)
-            elif implementation is not None and not inspect.isclass(implementation):
-                # It's an instance passed as implementation (backward compatibility)
-                self._register_internal(interface, instance=implementation)
-            else:
-                self._register_internal(
-                    interface, implementation, lifetime=ServiceLifetime.SINGLETON
-                )
+            self._register_internal(
+                interface, implementation, lifetime=ServiceLifetime.SINGLETON
+            )
 
         # Handle disposal handler
         if dispose_handler:
@@ -485,12 +478,11 @@ class DIContainer(IServiceContainer):
             registration = self._named_registrations[name]
             if registration.instance is not None:
                 return registration.instance
-            elif registration.factory:
+            if registration.factory:
                 return registration.factory(self)
-            else:
-                return self.create_instance(
-                    registration.implementation, registration.dependencies
-                )
+            return self.create_instance(
+                registration.implementation, registration.dependencies
+            )
 
         return self._resolve_internal(interface)
 
@@ -546,10 +538,16 @@ class DIContainer(IServiceContainer):
 
             elif registration.lifetime == ServiceLifetime.SCOPED:
                 # Check current scope
-                if self._current_scope:
-                    instance = self._current_scope.get_scoped_instance(service_type)
-                    if instance is not None:
-                        return instance
+                if (
+                    self._current_scope
+                    and (
+                        instance := self._current_scope.get_scoped_instance(
+                            service_type
+                        )
+                    )
+                    is not None
+                ):
+                    return instance
 
             # Mark as resolving
             self._resolving.add(service_type)
@@ -644,7 +642,7 @@ class DIContainer(IServiceContainer):
                                 if reg_type.__name__ == param_type:
                                     param_type = reg_type
                                     break
-                    except:
+                    except Exception:
                         # If we can't resolve, skip this parameter
                         if param.default != param.empty:
                             kwargs[param_name] = param.default
@@ -669,8 +667,7 @@ class DIContainer(IServiceContainer):
                         raise CircularDependencyError(
                             f"Circular dependency detected: {cycle}"
                         )
-                    else:
-                        kwargs[param_name] = self.resolve(param_type)
+                    kwargs[param_name] = self.resolve(param_type)
                 elif param.default != param.empty:
                     # Use default value
                     kwargs[param_name] = param.default
@@ -813,7 +810,7 @@ class DIContainer(IServiceContainer):
         type_name = service_type.__name__.lower()
         similar = []
 
-        for registered_type in self._registrations.keys():
+        for registered_type in self._registrations:
             registered_name = registered_type.__name__
             registered_lower = registered_name.lower()
 
@@ -845,7 +842,7 @@ class DIContainer(IServiceContainer):
         name_lower = name.lower()
         similar = []
 
-        for registered_name in self._named_registrations.keys():
+        for registered_name in self._named_registrations:
             registered_lower = registered_name.lower()
 
             # Check for substring match
