@@ -633,6 +633,15 @@ class SocketClient {
                 });
                 this.notifyEventUpdate();
                 console.log(`Event history loaded: ${data.events.length} events added to dashboard`);
+
+                // FIX: Dispatch custom event after history is loaded
+                // WHY: Allows dashboard to render panes with initial data
+                document.dispatchEvent(new CustomEvent('historyLoaded', {
+                    detail: {
+                        eventCount: data.events.length,
+                        totalAvailable: data.total_available
+                    }
+                }));
             } else if (Array.isArray(data)) {
                 // Handle legacy format for backward compatibility
                 console.log('Received legacy event history format:', data.length, 'events');
@@ -641,6 +650,14 @@ class SocketClient {
                     this.addEvent(transformedEvent, false);
                 });
                 this.notifyEventUpdate();
+
+                // FIX: Dispatch custom event for legacy format too
+                document.dispatchEvent(new CustomEvent('historyLoaded', {
+                    detail: {
+                        eventCount: data.length,
+                        totalAvailable: data.length
+                    }
+                }));
             }
         });
 
@@ -1389,6 +1406,12 @@ class SocketClient {
                 actualType = 'connected';
                 this.isConnected = true;
                 this.isConnecting = false;
+
+                // Expose socket globally when connected
+                if (!window.socket) {
+                    window.socket = this.socket;
+                    console.log('SocketClient: Exposed socket globally as window.socket');
+                }
             } else if (this.socket.connecting || this.isConnecting) {
                 actualStatus = 'Connecting...';
                 actualType = 'connecting';
@@ -1401,17 +1424,15 @@ class SocketClient {
             }
         }
 
-        // Check if UI needs updating
+        // Always update status to ensure consistency
+        this.updateConnectionStatusDOM(actualStatus, actualType);
+
+        // Also ensure state is consistent
         const statusElement = document.getElementById('connection-status');
         if (statusElement) {
             const currentText = statusElement.textContent.replace('●', '').trim();
-            const currentClass = statusElement.className;
-            const expectedClass = `status-badge status-${actualType}`;
-
-            // Update if status text or class doesn't match
-            if (currentText !== actualStatus || currentClass !== expectedClass) {
-                console.log(`SocketClient: Fallback update - was '${currentText}' (${currentClass}), now '${actualStatus}' (${expectedClass})`);
-                this.updateConnectionStatusDOM(actualStatus, actualType);
+            if (currentText !== actualStatus) {
+                console.log(`SocketClient: Status sync - updating from '${currentText}' to '${actualStatus}'`);
             }
         }
     }
