@@ -268,7 +268,10 @@ class ResponseTrackingManager:
     def track_stop_response(
         self, event: dict, session_id: str, metadata: dict, pending_prompts: dict
     ):
-        """Track response for stop events."""
+        """Track response for stop events.
+
+        Captures Claude API stop_reason and usage data for context management.
+        """
         if not (self.response_tracking_enabled and self.response_tracker):
             return
 
@@ -294,6 +297,37 @@ class ResponseTrackingManager:
                 # Add prompt timestamp to metadata
                 metadata["prompt_timestamp"] = prompt_data.get("timestamp")
 
+                # Capture Claude API stop_reason if available
+                if "stop_reason" in event:
+                    metadata["stop_reason"] = event["stop_reason"]
+                    if DEBUG:
+                        print(
+                            f"  - Captured stop_reason: {event['stop_reason']}",
+                            file=sys.stderr,
+                        )
+
+                # Capture Claude API usage data if available
+                if "usage" in event:
+                    usage_data = event["usage"]
+                    metadata["usage"] = {
+                        "input_tokens": usage_data.get("input_tokens", 0),
+                        "output_tokens": usage_data.get("output_tokens", 0),
+                        "cache_creation_input_tokens": usage_data.get(
+                            "cache_creation_input_tokens", 0
+                        ),
+                        "cache_read_input_tokens": usage_data.get(
+                            "cache_read_input_tokens", 0
+                        ),
+                    }
+                    if DEBUG:
+                        total_tokens = usage_data.get(
+                            "input_tokens", 0
+                        ) + usage_data.get("output_tokens", 0)
+                        print(
+                            f"  - Captured usage: {total_tokens} total tokens",
+                            file=sys.stderr,
+                        )
+
                 # Track the main Claude response
                 file_path = self.response_tracker.track_response(
                     agent_name="claude_main",
