@@ -21,7 +21,6 @@ multi-file implementation for better maintainability.
 
 import asyncio
 import json
-import os
 from dataclasses import dataclass, field
 from datetime import datetime, timezone
 from enum import Enum
@@ -113,7 +112,7 @@ class AgentProfileLoader(BaseService):
         super().__init__(name="agent_profile_loader", config=config)
 
         # Core configuration
-        self.working_directory = Path(os.getcwd())
+        self.working_directory = Path(Path.cwd())
         self.framework_path = self._detect_framework_path()
         self.user_home = Path.home()
 
@@ -457,7 +456,7 @@ class AgentProfileLoader(BaseService):
 
         if prompt_file.exists():
             try:
-                with open(prompt_file) as f:
+                with prompt_file.open() as f:
                     data = json.load(f)
                     for prompt_data in data:
                         prompt = ImprovedPrompt(
@@ -500,7 +499,7 @@ class AgentProfileLoader(BaseService):
 
             # Save to file
             prompt_file = self.improved_prompts_path / f"{agent_name}_prompts.json"
-            with open(prompt_file, "w") as f:
+            with prompt_file.open("w") as f:
                 json.dump(
                     [
                         {
