@@ -13,6 +13,6 @@ DESIGN DECISIONS:
 
 from .diagnostic_runner import DiagnosticRunner
 from .doctor_reporter import DoctorReporter
-from .models import DiagnosticResult, DiagnosticStatus
+from .models import DiagnosticResult
 
-__all__ = ["DiagnosticResult", "DiagnosticRunner", "DiagnosticStatus", "DoctorReporter"]
+__all__ = ["DiagnosticResult", "DiagnosticRunner", "DoctorReporter"]
