@@ -5,7 +5,6 @@ to enable monitor event forwarding via Socket.IO.
 """
 
 import json
-import os
 import shutil
 import stat
 import sys
@@ -24,7 +23,7 @@ class HookInstallerService:
         self.claude_dir = Path.home() / ".claude"
         self.settings_file = self.claude_dir / "settings.json"
 
-    def is_hooks_configured(self) -> bool:  # noqa: PLR0911
+    def is_hooks_configured(self) -> bool:
         """Check if hooks are configured in Claude settings.
 
         Returns:
@@ -35,7 +34,7 @@ class HookInstallerService:
                 self.logger.debug("Claude settings file does not exist")
                 return False
 
-            with open(self.settings_file) as f:
+            with self.settings_file.open() as f:
                 settings = json.load(f)
 
             # Check if hooks section exists
@@ -280,8 +279,8 @@ class HookInstallerService:
                 return False
 
             # Make sure the script is executable
-            st = os.stat(hook_script)
-            os.chmod(hook_script, st.st_mode | stat.S_IEXEC)
+            st = Path(hook_script).stat()
+            Path(hook_script).chmod(st.st_mode | stat.S_IEXEC)
             self.logger.debug(f"Made hook script executable: {hook_script}")
 
             hook_script_path = str(hook_script.absolute())
@@ -292,7 +291,7 @@ class HookInstallerService:
 
             # Load existing settings or create new
             if self.settings_file.exists():
-                with open(self.settings_file) as f:
+                with self.settings_file.open() as f:
                     settings = json.load(f)
                 self.logger.debug("Found existing Claude settings")
             else:
@@ -320,7 +319,7 @@ class HookInstallerService:
                 settings["hooks"][event_type] = [hook_config]
 
             # Write settings
-            with open(self.settings_file, "w") as f:
+            with self.settings_file.open("w") as f:
                 json.dump(settings, f, indent=2)
 
             self.logger.info(f"Updated Claude settings at: {self.settings_file}")
@@ -380,7 +379,7 @@ class HookInstallerService:
 
             self.logger.info("Removing Claude Code hooks...")
 
-            with open(self.settings_file) as f:
+            with self.settings_file.open() as f:
                 settings = json.load(f)
 
             hooks_removed = 0
@@ -422,7 +421,7 @@ class HookInstallerService:
                     del settings["hooks"]
 
             # Write updated settings
-            with open(self.settings_file, "w") as f:
+            with self.settings_file.open("w") as f:
                 json.dump(settings, f, indent=2)
 
             if hooks_removed > 0:
@@ -469,7 +468,7 @@ class HookInstallerService:
 
         try:
             if self.settings_file.exists():
-                with open(self.settings_file) as f:
+                with self.settings_file.open() as f:
                     settings = json.load(f)
 
                 if "hooks" in settings:
