@@ -26,6 +26,7 @@ from typing import Any, Dict
 import psutil
 
 from claude_mpm.config.paths import paths
+from claude_mpm.core.enums import HealthStatus, OperationResult, ServiceState
 from claude_mpm.core.logger import get_logger
 from claude_mpm.services.mcp_gateway.core.interfaces import (
     MCPToolDefinition,
@@ -168,20 +169,20 @@ class HealthCheckTool(BaseToolAdapter):
                 if i < len(check_results):
                     if isinstance(check_results[i], Exception):
                         results["checks"][check_name] = {
-                            "status": "error",
+                            "status": OperationResult.ERROR,
                             "error": str(check_results[i]),
                         }
                     else:
                         results["checks"][check_name] = check_results[i]
                 else:
                     results["checks"][check_name] = {
-                        "status": "timeout",
+                        "status": OperationResult.TIMEOUT,
                         "error": "Check timed out",
                     }
 
         except asyncio.TimeoutError:
             results["checks"]["timeout"] = {
-                "status": "error",
+                "status": OperationResult.ERROR,
                 "error": f"Health checks timed out after {timeout} seconds",
             }
 
@@ -194,7 +195,7 @@ class HealthCheckTool(BaseToolAdapter):
     async def _check_system_health(self, detailed: bool) -> Dict[str, Any]:
         """Check system health (CPU, memory, disk, etc.)."""
         check_result = {
-            "status": "healthy",
+            "status": ServiceState.RUNNING,
             "checks": {},
             "warnings": [],
             "errors": [],
@@ -219,7 +220,7 @@ class HealthCheckTool(BaseToolAdapter):
 
             if memory_usage > 90:
                 check_result["errors"].append("High memory usage detected")
-                check_result["status"] = "unhealthy"
+                check_result["status"] = HealthStatus.UNHEALTHY
             elif memory_usage > 80:
                 check_result["warnings"].append("Elevated memory usage")
 
@@ -232,7 +233,7 @@ class HealthCheckTool(BaseToolAdapter):
 
             if cpu_usage > 95:
                 check_result["errors"].append("High CPU usage detected")
-                check_result["status"] = "unhealthy"
+                check_result["status"] = HealthStatus.UNHEALTHY
             elif cpu_usage > 80:
                 check_result["warnings"].append("Elevated CPU usage")
 
@@ -248,7 +249,7 @@ class HealthCheckTool(BaseToolAdapter):
 
                 if disk_usage_percent > 95:
                     check_result["errors"].append("Disk space critically low")
-                    check_result["status"] = "unhealthy"
+                    check_result["status"] = HealthStatus.UNHEALTHY
                 elif disk_usage_percent > 85:
                     check_result["warnings"].append("Disk space running low")
 
@@ -262,7 +263,7 @@ class HealthCheckTool(BaseToolAdapter):
             }
 
         except Exception as e:
-            check_result["status"] = "error"
+            check_result["status"] = HealthStatus.UNHEALTHY
             check_result["errors"].append(f"System health check failed: {e}")
 
         return check_result
@@ -270,7 +271,7 @@ class HealthCheckTool(BaseToolAdapter):
     async def _check_gateway_health(self, detailed: bool) -> Dict[str, Any]:
         """Check MCP Gateway health."""
         check_result = {
-            "status": "healthy",
+            "status": ServiceState.RUNNING,
             "checks": {},
             "warnings": [],
             "errors": [],
@@ -302,10 +303,10 @@ class HealthCheckTool(BaseToolAdapter):
 
             if not mcp_dir.exists():
                 check_result["errors"].append("MCP directory does not exist")
-                check_result["status"] = "unhealthy"
+                check_result["status"] = HealthStatus.UNHEALTHY
 
         except Exception as e:
-            check_result["status"] = "error"
+            check_result["status"] = HealthStatus.UNHEALTHY
             check_result["errors"].append(f"Gateway health check failed: {e}")
 
         return check_result
@@ -313,7 +314,7 @@ class HealthCheckTool(BaseToolAdapter):
     async def _check_tools_health(self, detailed: bool) -> Dict[str, Any]:
         """Check MCP tools health."""
         check_result = {
-            "status": "healthy",
+            "status": ServiceState.RUNNING,
             "checks": {},
             "warnings": [],
             "errors": [],
@@ -353,11 +354,11 @@ class HealthCheckTool(BaseToolAdapter):
                 )
 
             if len(available_essential) == 0:
-                check_result["status"] = "unhealthy"
+                check_result["status"] = HealthStatus.UNHEALTHY
                 check_result["errors"].append("No essential tools available")
 
         except Exception as e:
-            check_result["status"] = "error"
+            check_result["status"] = HealthStatus.UNHEALTHY
             check_result["errors"].append(f"Tools health check failed: {e}")
 
         return check_result
@@ -365,7 +366,7 @@ class HealthCheckTool(BaseToolAdapter):
     async def _check_config_health(self, detailed: bool) -> Dict[str, Any]:
         """Check configuration health."""
         check_result = {
-            "status": "healthy",
+            "status": ServiceState.RUNNING,
             "checks": {},
             "warnings": [],
             "errors": [],
@@ -401,7 +402,7 @@ class HealthCheckTool(BaseToolAdapter):
             }
 
         except Exception as e:
-            check_result["status"] = "error"
+            check_result["status"] = HealthStatus.UNHEALTHY
             check_result["errors"].append(f"Config health check failed: {e}")
 
         return check_result
@@ -413,13 +414,13 @@ class HealthCheckTool(BaseToolAdapter):
 
         statuses = [check.get("status", "unknown") for check in checks.values()]
 
-        if "error" in statuses:
-            return "error"
-        if "unhealthy" in statuses:
+        # Check for unhealthy (handle both string and enum)
+        if HealthStatus.UNHEALTHY in statuses or "unhealthy" in statuses:
             return "unhealthy"
         if "warning" in statuses:
             return "warning"
-        if all(status == "healthy" for status in statuses):
+        # Check for healthy (handle both string and enum)
+        if all(status in (HealthStatus.HEALTHY, "healthy") for status in statuses):
             return "healthy"
         return "unknown"
 
@@ -436,19 +437,20 @@ class HealthCheckTool(BaseToolAdapter):
         for check_name, check_result in checks.items():
             status = check_result.get("status", "unknown")
 
-            if status == "healthy":
+            # Check for healthy (handle both string and enum)
+            if status in (HealthStatus.HEALTHY, "healthy"):
                 summary["healthy"] += 1
-            elif status in ["warning", "unhealthy"]:
+            elif status in ["warning", HealthStatus.UNHEALTHY, "unhealthy"]:
                 summary["warnings"] += 1
                 # Collect warning messages
                 warnings = check_result.get("warnings", [])
                 for warning in warnings:
                     summary["issues"].append(f"{check_name}: {warning}")
-            elif status == "error":
-                summary["errors"] += 1
-                # Collect error messages
-                errors = check_result.get("errors", [])
-                for error in errors:
-                    summary["issues"].append(f"{check_name}: {error}")
+                # Collect error messages if status is unhealthy
+                if status in (HealthStatus.UNHEALTHY, "unhealthy"):
+                    summary["errors"] += 1
+                    errors = check_result.get("errors", [])
+                    for error in errors:
+                        summary["issues"].append(f"{check_name}: {error}")
 
         return summary
