@@ -22,6 +22,7 @@ import tty
 from typing import Any, Dict, List, Optional
 
 from claude_mpm.core.base_service import BaseService
+from claude_mpm.core.enums import OperationResult, ServiceState
 from claude_mpm.services.core.interfaces import SubprocessLauncherInterface
 
 
@@ -62,9 +63,17 @@ class SubprocessLauncherService(BaseService, SubprocessLauncherInterface):
         try:
             env = kwargs.get("env", self.prepare_subprocess_environment())
             self.launch_subprocess_interactive(command, env)
-            return {"status": "launched", "command": command, "method": "interactive"}
+            return {
+                "status": OperationResult.SUCCESS,
+                "command": command,
+                "method": "interactive",
+            }
         except Exception as e:
-            return {"status": "failed", "error": str(e), "command": command}
+            return {
+                "status": OperationResult.FAILED,
+                "error": str(e),
+                "command": command,
+            }
 
     async def launch_subprocess_async(
         self, command: List[str], **kwargs
@@ -109,7 +118,7 @@ class SubprocessLauncherService(BaseService, SubprocessLauncherInterface):
         # For now, return unknown status
         return {
             "process_id": process_id,
-            "status": "unknown",
+            "status": OperationResult.UNKNOWN,
             "message": "Process tracking not implemented",
         }
 
@@ -160,7 +169,7 @@ class SubprocessLauncherService(BaseService, SubprocessLauncherInterface):
             # Notify WebSocket clients
             if self.websocket_server:
                 self.websocket_server.claude_status_changed(
-                    status="running",
+                    status=ServiceState.RUNNING,
                     pid=process.pid,
                     message="Claude subprocess started",
                 )
@@ -195,7 +204,7 @@ class SubprocessLauncherService(BaseService, SubprocessLauncherInterface):
             # Notify WebSocket clients
             if self.websocket_server:
                 self.websocket_server.claude_status_changed(
-                    status="stopped",
+                    status=ServiceState.STOPPED,
                     message=f"Claude subprocess exited with code {process.returncode}",
                 )
 
