@@ -23,6 +23,7 @@ from datetime import datetime, timezone
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple, Union
 
+from claude_mpm.core.enums import HealthStatus, OperationResult
 from claude_mpm.core.logging_utils import get_logger
 
 logger = get_logger(__name__)
@@ -256,7 +257,7 @@ def verify_deployment_health(
         Health status dictionary
     """
     health = {
-        "status": "unknown",
+        "status": OperationResult.UNKNOWN,
         "timestamp": datetime.now(timezone.utc).isoformat(),
         "checks": {},
         "errors": [],
@@ -292,14 +293,14 @@ def verify_deployment_health(
 
         # Determine overall status
         if all(health["checks"].values()):
-            health["status"] = "healthy"
+            health["status"] = HealthStatus.HEALTHY
         elif any(health["checks"].values()):
-            health["status"] = "degraded"
+            health["status"] = HealthStatus.DEGRADED
         else:
-            health["status"] = "unhealthy"
+            health["status"] = HealthStatus.UNHEALTHY
 
     except Exception as e:
-        health["status"] = "error"
+        health["status"] = HealthStatus.UNKNOWN
         health["errors"].append(str(e))
 
     return health
